@@ -1,5 +1,12 @@
-# This file is part of GNU Health.  The COPYRIGHT file at the top level of
-# this repository contains the full copyright notices and license terms.
+# SPDX-FileCopyrightText: 2009-2013 Bertrand Chenal
+# SPDX-FileCopyrightText: 2009-2016 B2CK
+# SPDX-FileCopyrightText: 2009-2016 Cédric Krier
+# SPDX-FileCopyrightText: 2009-2016 Tryton Foundation <info@tryton.org>
+# SPDX-FileCopyrightText: 2016-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2016-2023 Luis Falcón <falcon@gnuhealth.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 import uuid
 import vobject
 import dateutil.tz
@@ -1497,7 +1504,12 @@ class EventAttendee(AttendeeMixin, ModelSQL, ModelView):
 
 
 class DateMixin:
-    _rec_name = 'datetime'
+    # _rec_name = 'datetime'
+    # _rec_name needs to be char or  txt
+    def get_rec_name(self, name):
+        if self.datetime:
+            return str(self.datetime)
+
     date = fields.Boolean(
         'Is Date',
         help='Ignore time of field "Date", but handle as date only.')
@@ -1541,7 +1553,12 @@ class DateMixin:
 class EventRDate(DateMixin, ModelSQL, ModelView):
     'Recurrence Date'
     __name__ = 'calendar.event.rdate'
-    _rec_name = 'datetime'
+    # _rec_name = 'datetime'
+
+    def get_rec_name(self, name):
+        if self.datetime:
+            return str(self.datetime)
+
     event = fields.Many2One(
         'calendar.event', 'Event', ondelete='CASCADE',
         select=True, required=True)
@@ -1591,7 +1608,11 @@ class EventExDate(EventRDate):
 
 
 class RRuleMixin(Model):
-    _rec_name = 'freq'
+    # _rec_name = 'freq'
+    def get_rec_name(self, name):
+        if self.freq:
+            return str(self.freq)
+
     freq = fields.Selection([
         ('secondly', 'Secondly'),
         ('minutely', 'Minutely'),
