@@ -1,25 +1,10 @@
-##############################################################################
+# Copyright (C) 2008-2023 Luis Falcon <lfalcon@gnusolidario.org>
+# Copyright (C) 2011-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
 #
-#    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#
-#
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 import datetime
 import decimal
 from trytond.wizard import Wizard
@@ -48,6 +33,8 @@ class CreateServiceInvoice(Wizard):
             # mutually exclusive.
 
             discount = {}
+            # If the policy line contains both values (percentage and
+            # fixed price, the percentage value will take over.
             if insurance.plan_id.product_policy:
                 for policy in insurance.plan_id.product_policy:
                     # Check first for product
@@ -57,6 +44,11 @@ class CreateServiceInvoice(Wizard):
                             discount['type'] = 'pct'
                             return discount
 
+                        if policy.price:
+                            discount['value'] = policy.price
+                            discount['type'] = 'fixed'
+                            return discount
+
                 for policy in insurance.plan_id.product_policy:
                     # Then, if there's no product, check for the category
                     if (policy.product_category in product.categories):
@@ -204,7 +196,10 @@ class CreateServiceInvoice(Wizard):
                                         str_disc = str(discount['value']) + '%'
                                         desc = line.desc + " (Discnt " + \
                                             str(str_disc) + ")"
-
+                                    # Use the fixed price
+                                    else:
+                                        unit_price = discount['value']
+                                        desc = f"{line.desc} (policy plan)"
                     invoice_lines.append(('create', [{
                             'origin': str(line),
                             'product': line.product.id,
