@@ -1,27 +1,16 @@
-##############################################################################
+# SPDX-FileCopyrightText: 2019-2022 Chris Zimmerman <chris@teffalump.com>
+# SPDX-FileCopyrightText: 2021-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2021-2023 GNU Solidario <health@gnusolidario.org>
 #
-#    GNU Health: The Free Health and Hospital Information System
-#                   
-#                   *** ORTHANC INTEGRATION PACKAGE ***
-#
-#    Copyright (C) 2019-2022 Chris Zimmerman <chris@teffalump.com>
-#    Copyright (C) 2021-2022 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2021-2022 GNU Solidario <info@gnusolidario.org>
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# SPDX-License-Identifier: GPL-3.0-or-later
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                         HEALTH ORTHANC package                        #
+#                     health_orthanc.py: main module                    #
+#########################################################################
 
 from trytond.model import ModelView, ModelSQL, fields, Unique
 from trytond.pool import Pool
@@ -360,7 +349,7 @@ class OrthancStudy(ModelSQL, ModelView):
         fields.Char(
             "URL", help="Link to study in Orthanc Explorer"), "get_link")
 
-    imaging_test = fields.Many2One("gnuhealth.imaging.test.result", "Test")
+    imaging_test = fields.Many2One("gnuhealth.imaging.test.result", "Study")
 
     def get_link(self, name):
         pre = "".join([self.server.domain.rstrip("/"), "/"])
