@@ -1,31 +1,15 @@
-##############################################################################
+# Copyright (C) 2008-2023 Luis Falcon <lfalcon@gnusolidario.org>
+# Copyright (C) 2011-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
 #
-#    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#
-#
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 from trytond.model import ModelView, fields
 from trytond.pyson import Eval, Equal
 from trytond.wizard import Wizard
 from trytond.pool import Pool
 
-
 __all__ = ['RequestPatientLabTestStart', 'RequestPatientLabTest']
 
 
@@ -34,6 +18,15 @@ class RequestPatientLabTestStart(ModelView):
     'Request Patient Lab Test Start'
     __name__ = 'gnuhealth.patient.lab.test.request.start'
 
+    ungroup_tests = fields.Boolean(
+        'Ungroup',
+        help="Check if you DO NOT want to include each individual lab test"
+             " from this order in the lab test generation step."
+             " This is useful when some services are not provided in"
+             " the same institution.\n"
+             "In this case, you need to individually update the service"
+             " document from each individual test")
+
     service = fields.Many2One(
         'gnuhealth.health_service', 'Service',
         domain=[('patient', '=', Eval('patient'))], depends=['patient'],
@@ -53,6 +46,30 @@ class RequestPatientLabTest(Wizard):
         if sequence:
             return sequence.get()
 
+    def append_services(self, labtest, service):
+        """ If the ungroup flag is not set, append the lab test
+            to the associated health service
+        """
+        HealthService = Pool().get('gnuhealth.health_service')
+
+        hservice = []
+
+        service_data = {}
+        service_lines = []
+
+        # Add the labtest to the service document
+
+        service_lines.append(('create', [{
+            'product': labtest.product_id.id,
+            'desc': labtest.product_id.rec_name,
+            'qty': 1
+            }]))
+
+        hservice.append(service)
+        service_data['service_line'] = service_lines
+
+        HealthService.write(hservice, service_data)
+
     def transition_request(self):
         PatientLabTest = Pool().get('gnuhealth.patient.lab.test')
         request_number = self.generate_code()
@@ -71,7 +88,10 @@ class RequestPatientLabTest(Wizard):
 
             if self.start.service:
                 lab_test['service'] = self.start.service.id
-
+                # Append the test directly to the health service document
+                # if the Ungroup flag is not set (default).
+                if not self.start.ungroup_tests:
+                    self.append_services(test, self.start.service)
             lab_tests.append(lab_test)
 
         PatientLabTest.create(lab_tests)
