@@ -1,34 +1,27 @@
-##############################################################################
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
 #
-#    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# SPDX-License-Identifier: GPL-3.0-or-later
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                      HEALTH SOCIOECONOMICS package                    #
+#                  health_socioeconomics.py: main module                #
+#########################################################################
+
 from dateutil.relativedelta import relativedelta
 from datetime import datetime
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pyson import Eval, Equal
+from trytond.pool import PoolMeta
 from trytond.modules.health.core import get_health_professional
 
 __all__ = ['Party', 'PatientSESAssessment', 'GnuHealthPatient']
 
 
-class Party (ModelSQL, ModelView):
+class Party (metaclass=PoolMeta):
     __name__ = 'party.party'
 
     occupation = fields.Many2One('gnuhealth.occupation', 'Occupation')
@@ -211,7 +204,7 @@ class PatientSESAssessment(ModelSQL, ModelView):
 
     # Show the gender and age upon entering the patient
     # These two are function fields (don't exist at DB level)
-    @fields.depends('patient')
+    @fields.depends('patient', '_parent_patient.name')
     def on_change_patient(self):
         self.gender = self.patient.gender
         self.computed_age = self.patient.age
