@@ -1,20 +1,19 @@
 #!/usr/bin/env python
-#    Copyright (C) 2017-2022 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2017-2022 GNU Solidario <health@gnusolidario.org>
-#    Copyright (C) 2012-2017 Cédric Krier
+# SPDX-FileCopyrightText: 2017-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2017-2023 GNU Solidario <health@gnusolidario.org>
+# SPDX-FileCopyrightText: 2012-2017 Cédric Krier <cedric.krier@b2ck.com>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                        HEALTH WEBDAV3 SERVER                          #
+#                      setup.py: Setuptools file                        #
+#########################################################################
 
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from setuptools import setup
 import re
@@ -55,7 +54,7 @@ for dep in info.get('depends', []):
 setup(name='gnuhealth_webdav3_server',
       version=info.get('version', '0.0.1'),
       description='GNU Health WebDAV server for Python 3',
-      long_description=read('README'),
+      long_description=read('README.rst'),
       author='GNU Solidario',
       author_email='health@gnusolidario.org',
       url='https://www.gnuhealth.org',
